==> jc-1.4.0.tar.gz: gnu/xml/transform/FunctionAvailableFunction.h <==
// class gnu.xml.transform.FunctionAvailableFunction

// class file dependencies
// @dep_class 15fb3c13a7d33c99 gnu_xml_transform_FunctionAvailableFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_FunctionAvailableFunction_H_
#define _JC_gnu_xml_transform_FunctionAvailableFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_javax_xml_namespace_NamespaceContext$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs	_jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs	_jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$refs	_jc_gnu_xml_transform_FunctionAvailableFunction$refs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs	_jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$object	_jc_gnu_xml_transform_FunctionAvailableFunction$object;

typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct	_jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct;
typedef const struct _jc_gnu_xml_transform_FunctionAvailableFunction$vmethods	_jc_gnu_xml_transform_FunctionAvailableFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtable	_jc_gnu_xml_transform_FunctionAvailableFunction$vtable;
typedef const struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtype	_jc_gnu_xml_transform_FunctionAvailableFunction$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct {
	struct _jc_object	*xpathFunctions;
	struct _jc_object	*xsltFunctions;
};
extern _jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct _jc_gnu_xml_transform_FunctionAvailableFunction$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_FunctionAvailableFunction$method$_init$c79ae2127c83a924(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *);

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_FunctionAvailableFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_java_lang_Object$object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FunctionAvailableFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *);
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FunctionAvailableFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *, jint, jint);
extern void _jc_gnu_xml_transform_FunctionAvailableFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *);

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$setArguments$09123773dfa6e512;

// Static methods
extern void _jc_gnu_xml_transform_FunctionAvailableFunction$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_gnu_xml_transform_FunctionAvailableFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_java_lang_Object$object *);
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *);
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *, jint, jint);
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *);
};

// Vtable
struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_FunctionAvailableFunction$vmethods	gnu_xml_transform_FunctionAvailableFunction;
};

// Vtype
struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_FunctionAvailableFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs {
	struct _jc_object	*nsctx;
	struct _jc_object	*args;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$refs {
    _jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs	gnu_xml_transform_FunctionAvailableFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs	gnu_xml_transform_FunctionAvailableFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_FunctionAvailableFunction$object {
	_jc_gnu_xml_transform_FunctionAvailableFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_FunctionAvailableFunction$vtype	*vtype;
	_jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_FunctionAvailableFunction$vtype _jc_gnu_xml_transform_FunctionAvailableFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_FunctionAvailableFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_FunctionAvailableFunction$class_object;

#endif	/* _JC_gnu_xml_transform_FunctionAvailableFunction_H_ */

==> jc-1.4.5.tar.gz: gnu/xml/transform/FunctionAvailableFunction.h <==
// class gnu.xml.transform.FunctionAvailableFunction

// class file dependencies
// @dep_class 15fb3c13a7d33c99 gnu_xml_transform_FunctionAvailableFunction
// @dep_class d90c61647700b7f6 gnu_xml_xpath_Expr
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header gnu_xml_xpath_Expr

#include "gnu/xml/xpath/Expr.h"

#ifndef _JC_gnu_xml_transform_FunctionAvailableFunction_H_
#define _JC_gnu_xml_transform_FunctionAvailableFunction_H_

// Forward structure declarations
struct _jc_gnu_xml_xpath_Expr$object;
struct _jc_java_lang_Class$object;
struct _jc_java_lang_Object$object;
struct _jc_java_util_Collection$object;
struct _jc_java_util_List$object;
struct _jc_javax_xml_namespace_NamespaceContext$object;
struct _jc_org_w3c_dom_Node$object;

// Typedefs
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs	_jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs	_jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$refs	_jc_gnu_xml_transform_FunctionAvailableFunction$refs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs	_jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs;
typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$object	_jc_gnu_xml_transform_FunctionAvailableFunction$object;

typedef struct _jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct	_jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct;
typedef const struct _jc_gnu_xml_transform_FunctionAvailableFunction$vmethods	_jc_gnu_xml_transform_FunctionAvailableFunction$vmethods;
typedef const struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtable	_jc_gnu_xml_transform_FunctionAvailableFunction$vtable;
typedef const struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtype	_jc_gnu_xml_transform_FunctionAvailableFunction$vtype;

// Class fields structure
struct _jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct {
	struct _jc_object	*xpathFunctions;
	struct _jc_object	*xsltFunctions;
};
extern _jc_gnu_xml_transform_FunctionAvailableFunction$fields_struct _jc_gnu_xml_transform_FunctionAvailableFunction$class_fields;

// Constructors
extern void _jc_gnu_xml_transform_FunctionAvailableFunction$method$_init$c79ae2127c83a924(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual methods
extern struct _jc_gnu_xml_xpath_Expr$object *_jc_gnu_xml_transform_FunctionAvailableFunction$method$clone$8aac957948447f2f(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FunctionAvailableFunction$method$evaluate$f399496e60bca5df(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
extern struct _jc_java_lang_Object$object *_jc_gnu_xml_transform_FunctionAvailableFunction$method$evaluate$8764614230b47559(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
extern void _jc_gnu_xml_transform_FunctionAvailableFunction$method$setArguments$09123773dfa6e512(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;

// Virtual method descriptors
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$clone$8aac957948447f2f;
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$evaluate$f399496e60bca5df;
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$evaluate$8764614230b47559;
extern _jc_method _jc_gnu_xml_transform_FunctionAvailableFunction$method_info$setArguments$09123773dfa6e512;

// Static methods
extern void _jc_gnu_xml_transform_FunctionAvailableFunction$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_gnu_xml_transform_FunctionAvailableFunction$vmethods {
	struct _jc_gnu_xml_xpath_Expr$object	*(*clone$8aac957948447f2f)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_java_lang_Object$object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$f399496e60bca5df)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
	struct _jc_java_lang_Object$object	*(*evaluate$8764614230b47559)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *, jint, jint) _JC_JCNI_ATTR;
	void	(*setArguments$09123773dfa6e512)(_jc_env *, struct _jc_gnu_xml_transform_FunctionAvailableFunction$object *, struct _jc_object *) _JC_JCNI_ATTR;
};

// Vtable
struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_gnu_xml_xpath_Expr$vmethods	gnu_xml_xpath_Expr;
	_jc_gnu_xml_transform_FunctionAvailableFunction$vmethods	gnu_xml_transform_FunctionAvailableFunction;
};

// Vtype
struct _jc_gnu_xml_transform_FunctionAvailableFunction$vtype {
	_jc_type			type;
	_jc_gnu_xml_transform_FunctionAvailableFunction$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs {
	struct _jc_object	*nsctx;
	struct _jc_object	*args;
};

// Reference instance fields (object)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$refs {
    _jc_gnu_xml_transform_FunctionAvailableFunction$sub_refs	gnu_xml_transform_FunctionAvailableFunction;
    _jc_gnu_xml_xpath_Expr$sub_refs	gnu_xml_xpath_Expr;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_gnu_xml_xpath_Expr$sub_nonrefs	gnu_xml_xpath_Expr;
    _jc_gnu_xml_transform_FunctionAvailableFunction$sub_nonrefs	gnu_xml_transform_FunctionAvailableFunction;
};

// Object instance structure
struct _jc_gnu_xml_transform_FunctionAvailableFunction$object {
	_jc_gnu_xml_transform_FunctionAvailableFunction$refs	refs[0];
	_jc_word		lockword;
	_jc_gnu_xml_transform_FunctionAvailableFunction$vtype	*vtype;
	_jc_gnu_xml_transform_FunctionAvailableFunction$nonrefs	nonrefs;
};

// Type structure
extern _jc_gnu_xml_transform_FunctionAvailableFunction$vtype _jc_gnu_xml_transform_FunctionAvailableFunction$type;

// Array types class info structures
_JC_DECL_ARRAYS(gnu_xml_transform_FunctionAvailableFunction, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_gnu_xml_transform_FunctionAvailableFunction$class_object;

#endif	/* _JC_gnu_xml_transform_FunctionAvailableFunction_H_ */
